//
// This code is part of https://developer.mescius.com/document-solutions/dot-net-word-api/demos.
// Copyright (c) MESCIUS inc. All rights reserved.
//
using System;
using System.IO;
using System.Drawing;
using System.Collections.Generic;
using System.Linq;
using GrapeCity.Documents.Word;

namespace DsWordWeb.Demos
{
    // This sample demonstrates all available shape geometry types.
    public class ShapeGeometryTypes
    {
        public GcWordDocument CreateDocx()
        {
            var doc = new GcWordDocument();
            var shapes = AddGeometryTypes(doc, new SizeF(100, 100));
            doc.Body.Paragraphs.Insert($"Shape geometry types ({shapes.Count})", doc.Styles[BuiltInStyleId.Title], InsertLocation.Start);
            return doc;

        }

        /// <summary>
        /// Adds a paragraph with a single empty run, and adds a shape for each available GeometryType.
        /// The fill and line colors of the shapes are varied.
        /// </summary>
        /// <param name="doc">The target document.</param>
        /// <param name="size">The size of shapes to create.</param>
        /// <param name="count">The maximum number of shapes to create (-1 for no limit).</param>
        /// <param name="skipUnfillable">Add only shapes that support fills.</param>
        /// <param name="noNames">Do not add geometry names as shape text frames.</param>
        /// <returns>The list of shapes added to the document.</returns>
        private static List<Shape> AddGeometryTypes(GcWordDocument doc, SizeF size, int count = -1, bool skipUnfillable = false, bool noNames = false)
        {
            // Line and fill colors:
            Color[] lines = new Color[] { Color.Blue, Color.SlateBlue, Color.Navy, Color.Indigo, Color.BlueViolet, Color.CadetBlue, };
            int line = 0;
            Color[] fills = new Color[] { Color.MistyRose, Color.BurlyWood, Color.Coral, Color.Goldenrod, Color.Orchid, Color.Orange, Color.PaleVioletRed, };
            int fill = 0;

            // The supported geometry types:
            var geoms = Enum.GetValues(typeof(GeometryType));

            // Add a paragraph and a run where the shapes will live:
            doc.Body.Paragraphs.Add("");
            Run run = doc.Body.Runs.Last;

            var shapes = new List<Shape>();
            foreach (GeometryType g in geoms)
            {
                // Line geometries do not support fills:
                if (skipUnfillable && g.IsLineGeometry())
                    continue;

                if (count-- == 0)
                    break;

                float w = size.Width, h = size.Height;
                var shape = run.GetRange().Shapes.Add(w, h, g);
                if (!g.IsLineGeometry())
                {
                    shape.Fill.Type = FillType.Solid;
                    shape.Fill.SolidFill.RGB = fills[fill < fills.Length - 1 ? ++fill : (fill = 0)];
                }
                shape.Line.Width = 3;
                shape.Line.Fill.SolidFill.RGB = lines[line < lines.Length - 1 ? ++line : (line = 0)];
                if (!noNames && g.TextFrameSupported())
                    shape.AddTextFrame(g.ToString());
                shape.AlternativeText = $"This is shape {g}";
                shape.Size.EffectExtent.AllEdges = 8;
                shapes.Add(shape);
            }
            return shapes;
        }
    }
}
